@@ -5,13 +5,9 @@
 
 :Author:
     David Young
-
-:Date Created:
-    March 11, 2016
 """
 import os
 
-
 def getpackagepath():
     """
     *getpackagepath*
